@@ -23,6 +23,7 @@ from tencentcloud.cdn.v20180606 import models
 class CdnClient(AbstractClient):
     _apiVersion = '2018-06-06'
     _endpoint = 'cdn.tencentcloudapi.com'
+    _service = 'cdn'
 
 
     def AddCdnDomain(self, request):
@@ -986,8 +987,7 @@ class CdnClient(AbstractClient):
 
     def PushUrlsCache(self, request):
         """This API is used to cache specified URL resources to CDN nodes. You can specify acceleration regions for the prefetch.
-        By default, a maximum of 1,000 URLs can be prefetched per day either within or outside Mainland China, and up to 20 tasks can be submitted at a time.
-        This API is in beta test and not fully available yet. Please stay tuned.
+        By default, a maximum of 1000 URLs can be prefetched per day either within or outside Chinese mainland, and up to 20 tasks can be submitted at a time.
 
         :param request: Request instance for PushUrlsCache.
         :type request: :class:`tencentcloud.cdn.v20180606.models.PushUrlsCacheRequest`
