@@ -23,6 +23,7 @@ from tencentcloud.ckafka.v20190819 import models
 class CkafkaClient(AbstractClient):
     _apiVersion = '2019-08-19'
     _endpoint = 'ckafka.tencentcloudapi.com'
+    _service = 'ckafka'
 
 
     def CreateAcl(self, request):
@@ -670,90 +671,6 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def FetchMessageByOffset(self, request):
-        """This API is used to query messages based on a specified offset position.
-
-        :param request: Request instance for FetchMessageByOffset.
-        :type request: :class:`tencentcloud.ckafka.v20190819.models.FetchMessageByOffsetRequest`
-        :rtype: :class:`tencentcloud.ckafka.v20190819.models.FetchMessageByOffsetResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("FetchMessageByOffset", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.FetchMessageByOffsetResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def FetchMessageListByOffset(self, request):
-        """This API is used to query the message list based on an offset.
-
-        :param request: Request instance for FetchMessageListByOffset.
-        :type request: :class:`tencentcloud.ckafka.v20190819.models.FetchMessageListByOffsetRequest`
-        :rtype: :class:`tencentcloud.ckafka.v20190819.models.FetchMessageListByOffsetResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("FetchMessageListByOffset", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.FetchMessageListByOffsetResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
-    def FetchMessageListByTimestamp(self, request):
-        """This API is used to query the message list based on a timestamp.
-
-        :param request: Request instance for FetchMessageListByTimestamp.
-        :type request: :class:`tencentcloud.ckafka.v20190819.models.FetchMessageListByTimestampRequest`
-        :rtype: :class:`tencentcloud.ckafka.v20190819.models.FetchMessageListByTimestampResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("FetchMessageListByTimestamp", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.FetchMessageListByTimestampResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def ModifyGroupOffsets(self, request):
         """This API is used to set the consumer group (Groups) offset.
 
